essentials

package module
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 7, 2026 License: CC0-1.0 Imports: 7 Imported by: 0

README

lem-cli-essentials

Tiny library for configuration and command line options; to save time in large programs implemented as a bunch of CLI executables. And, it also makes things more consistent.

Large microservice monsters? Same CLI everywhere, baby!

Small hello world CLI that you vibecoded (please don't)? Well, I can't stop you since this thing is licensed under CC0.

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func AddCommonFlags

func AddCommonFlags(set *pflag.FlagSet)

func InitConfig

func InitConfig(cmd *cobra.Command, cfgFile string, v *viper.Viper, prefix string) error

func LoadConfig

func LoadConfig(file string, subconfigs []string, v *viper.Viper) error

Load the other configuration files for things like rabbitmq.

func ViperEnv

func ViperEnv(v *viper.Viper, envPrefix string)

Prepares your Viper for the environment.

Types

This section is empty.

Jump to